uses_entities

Attribute Macro uses_entities 

#[uses_entities]
Marks the impl block to enable entity tracking.

When applied to an impl block or individual method, automatically enables the ENABLE_ENTITY interest flag so entities are tracked during parsing.

Examples

#[observer]
#[uses_entities]
impl MyObs {
    // Now you can use #[on_entity] handlers
}