pub struct AddFan {Show 18 fields
pub active: Option<bool>,
pub bounds_mins: Option<CMsgVector>,
pub bounds_maxs: Option<CMsgVector>,
pub fan_origin: Option<CMsgVector>,
pub fan_origin_offset: Option<CMsgVector>,
pub fan_direction: Option<CMsgVector>,
pub force: Option<f32>,
pub fan_force_curve: Option<String>,
pub falloff: Option<bool>,
pub pull_towards_point: Option<bool>,
pub curve_min_dist: Option<f32>,
pub curve_max_dist: Option<f32>,
pub fan_type: Option<u32>,
pub cone_start_radius: Option<f32>,
pub cone_end_radius: Option<f32>,
pub cone_length: Option<f32>,
pub entity_handle: Option<u32>,
pub attachment_name: Option<String>,
}Fields
active: Option<bool>bounds_mins: Option<CMsgVector>bounds_maxs: Option<CMsgVector>fan_origin: Option<CMsgVector>fan_origin_offset: Option<CMsgVector>fan_direction: Option<CMsgVector>force: Option<f32>fan_force_curve: Option<String>falloff: Option<bool>pull_towards_point: Option<bool>curve_min_dist: Option<f32>curve_max_dist: Option<f32>fan_type: Option<u32>cone_start_radius: Option<f32>cone_end_radius: Option<f32>cone_length: Option<f32>entity_handle: Option<u32>attachment_name: Option<String>Implementations
Sourceimpl AddFan
impl AddFan
Sourcepub fn active(&self) -> bool
pub fn active(&self) -> bool
Returns the value of active, or the default value if active is unset.
Sourcepub fn fan_force_curve(&self) -> &str
pub fn fan_force_curve(&self) -> &str
Returns the value of fan_force_curve, or the default value if fan_force_curve is unset.
Sourcepub fn falloff(&self) -> bool
pub fn falloff(&self) -> bool
Returns the value of falloff, or the default value if falloff is unset.
Sourcepub fn pull_towards_point(&self) -> bool
pub fn pull_towards_point(&self) -> bool
Returns the value of pull_towards_point, or the default value if pull_towards_point is unset.
Sourcepub fn curve_min_dist(&self) -> f32
pub fn curve_min_dist(&self) -> f32
Returns the value of curve_min_dist, or the default value if curve_min_dist is unset.
Sourcepub fn curve_max_dist(&self) -> f32
pub fn curve_max_dist(&self) -> f32
Returns the value of curve_max_dist, or the default value if curve_max_dist is unset.
Sourcepub fn fan_type(&self) -> u32
pub fn fan_type(&self) -> u32
Returns the value of fan_type, or the default value if fan_type is unset.
Sourcepub fn cone_start_radius(&self) -> f32
pub fn cone_start_radius(&self) -> f32
Returns the value of cone_start_radius, or the default value if cone_start_radius is unset.
Sourcepub fn cone_end_radius(&self) -> f32
pub fn cone_end_radius(&self) -> f32
Returns the value of cone_end_radius, or the default value if cone_end_radius is unset.
Sourcepub fn cone_length(&self) -> f32
pub fn cone_length(&self) -> f32
Returns the value of cone_length, or the default value if cone_length is unset.
Sourcepub fn entity_handle(&self) -> u32
pub fn entity_handle(&self) -> u32
Returns the value of entity_handle, or the default value if entity_handle is unset.
Sourcepub fn attachment_name(&self) -> &str
pub fn attachment_name(&self) -> &str
Returns the value of attachment_name, or the default value if attachment_name is unset.