pub struct SounddataT {Show 19 fields
pub origin_x: Option<i32>,
pub origin_y: Option<i32>,
pub origin_z: Option<i32>,
pub volume: Option<u32>,
pub delay_value: Option<f32>,
pub sequence_number: Option<i32>,
pub entity_index: Option<i32>,
pub channel: Option<i32>,
pub pitch: Option<i32>,
pub flags: Option<i32>,
pub sound_num: Option<u32>,
pub sound_num_handle: Option<u32>,
pub speaker_entity: Option<i32>,
pub random_seed: Option<i32>,
pub sound_level: Option<i32>,
pub is_sentence: Option<bool>,
pub is_ambient: Option<bool>,
pub guid: Option<u32>,
pub sound_resource_id: Option<u64>,
}Fields
origin_x: Option<i32>origin_y: Option<i32>origin_z: Option<i32>volume: Option<u32>delay_value: Option<f32>sequence_number: Option<i32>entity_index: Option<i32>channel: Option<i32>pitch: Option<i32>flags: Option<i32>sound_num: Option<u32>sound_num_handle: Option<u32>speaker_entity: Option<i32>random_seed: Option<i32>sound_level: Option<i32>is_sentence: Option<bool>is_ambient: Option<bool>guid: Option<u32>sound_resource_id: Option<u64>Implementations
Sourceimpl SounddataT
impl SounddataT
Sourcepub fn origin_x(&self) -> i32
pub fn origin_x(&self) -> i32
Returns the value of origin_x, or the default value if origin_x is unset.
Sourcepub fn origin_y(&self) -> i32
pub fn origin_y(&self) -> i32
Returns the value of origin_y, or the default value if origin_y is unset.
Sourcepub fn origin_z(&self) -> i32
pub fn origin_z(&self) -> i32
Returns the value of origin_z, or the default value if origin_z is unset.
Sourcepub fn volume(&self) -> u32
pub fn volume(&self) -> u32
Returns the value of volume, or the default value if volume is unset.
Sourcepub fn delay_value(&self) -> f32
pub fn delay_value(&self) -> f32
Returns the value of delay_value, or the default value if delay_value is unset.
Sourcepub fn sequence_number(&self) -> i32
pub fn sequence_number(&self) -> i32
Returns the value of sequence_number, or the default value if sequence_number is unset.
Sourcepub fn entity_index(&self) -> i32
pub fn entity_index(&self) -> i32
Returns the value of entity_index, or the default value if entity_index is unset.
Sourcepub fn channel(&self) -> i32
pub fn channel(&self) -> i32
Returns the value of channel, or the default value if channel is unset.
Sourcepub fn sound_num(&self) -> u32
pub fn sound_num(&self) -> u32
Returns the value of sound_num, or the default value if sound_num is unset.
Sourcepub fn sound_num_handle(&self) -> u32
pub fn sound_num_handle(&self) -> u32
Returns the value of sound_num_handle, or the default value if sound_num_handle is unset.
Sourcepub fn speaker_entity(&self) -> i32
pub fn speaker_entity(&self) -> i32
Returns the value of speaker_entity, or the default value if speaker_entity is unset.
Sourcepub fn random_seed(&self) -> i32
pub fn random_seed(&self) -> i32
Returns the value of random_seed, or the default value if random_seed is unset.
Sourcepub fn sound_level(&self) -> i32
pub fn sound_level(&self) -> i32
Returns the value of sound_level, or the default value if sound_level is unset.
Sourcepub fn is_sentence(&self) -> bool
pub fn is_sentence(&self) -> bool
Returns the value of is_sentence, or the default value if is_sentence is unset.
Sourcepub fn is_ambient(&self) -> bool
pub fn is_ambient(&self) -> bool
Returns the value of is_ambient, or the default value if is_ambient is unset.
Sourcepub fn sound_resource_id(&self) -> u64
pub fn sound_resource_id(&self) -> u64
Returns the value of sound_resource_id, or the default value if sound_resource_id is unset.