Display

Trait Display 

1.36.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Implementors

Source

impl Display for FieldValue

Source

impl Display for ClassError

Source

impl Display for CombatLogError

Source

impl Display for EntityError

Source

impl Display for FieldValueError

Source

impl Display for GameEventError

Source

impl Display for ParserError

Source

impl Display for SerializerError

Source

impl Display for StringTableError

1.86.0 · Source

impl Display for GetDisjointMutError

Source

impl Display for AsciiChar

1.34.0 · Source

impl Display for Infallible

1.17.0 · Source

impl Display for FromBytesWithNulError

1.60.0 · Source

impl Display for ErrorKind

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for VarError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

Source

impl Display for CodepointError

Source

impl Display for FromStrError

Source

impl Display for Utf16ArrayError

Source

impl Display for Utf16PairError

Source

impl Display for Utf16SliceError

Source

impl Display for Utf16TupleError

Source

impl Display for snap::error::Error

Source

impl Display for term::Error

Source

impl Display for term::terminfo::Error

Source

impl Display for term::terminfo::parm::Error

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

Source

impl Display for !

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl Display for Classes

Source

impl Display for Context

Source

impl Display for Entities

Source

impl Display for Entity

Source

impl Display for GameEvent<'_>

Source

impl Display for GameEventList

Source

impl Display for StringTable

Source

impl Display for StringTables

Source

impl Display for TryGetError

Source

impl Display for DecodeError

Source

impl Display for EncodeError

Source

impl Display for UnknownEnumValue

Source

impl Display for source2_demo::proto::prost::alloc::alloc::AllocError

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for ByteStr

Source

impl Display for ByteString

Source

impl Display for UnorderedKeyError

1.57.0 · Source

impl Display for source2_demo::proto::prost::alloc::collections::TryReserveError

1.58.0 · Source

impl Display for FromVecWithNulError

1.7.0 · Source

impl Display for IntoStringError

1.0.0 · Source

impl Display for NulError

1.0.0 · Source

impl Display for ParseBoolError

1.0.0 · Source

impl Display for source2_demo::proto::prost::alloc::str::Utf8Error

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.0.0 · Source

impl Display for String

1.35.0 · Source

impl Display for TryFromSliceError

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

1.34.0 · Source

impl Display for CharTryFromError

1.20.0 · Source

impl Display for ParseCharError

1.9.0 · Source

impl Display for DecodeUtf16Error

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

1.59.0 · Source

impl Display for TryFromCharError

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.4.0 · Source

impl Display for AddrParseError

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

1.0.0 · Source

impl Display for ParseIntError

1.34.0 · Source

impl Display for TryFromIntError

1.0.0 · Source

impl Display for ParseFloatError

1.26.0 · Source

impl Display for Location<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.65.0 · Source

impl Display for Backtrace

1.0.0 · Source

impl Display for JoinPathsError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.56.0 · Source

impl Display for WriterPanicked

1.0.0 · Source

impl Display for std::io::error::Error

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for NormalizeError

1.7.0 · Source

impl Display for StripPrefixError

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

1.0.0 · Source

impl Display for RecvError

Source

impl Display for WouldBlock

1.26.0 · Source

impl Display for AccessError

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for allocator_api2::stable::alloc::AllocError

Source

impl Display for allocator_api2::stable::raw_vec::TryReserveError

Source

impl Display for anyhow::Error

Source

impl Display for ParseError

Source

impl Display for EmptyStrError

Source

impl Display for NonAsciiError

Source

impl Display for NonBmpError

Source

impl Display for encode_unicode::errors::Utf8Error

Source

impl Display for Utf16FirstUnitError

Source

impl Display for Utf8Char

Source

impl Display for Utf16Char

Source

impl Display for Table

Source

impl Display for serde_core::de::value::Error

1.0.0 · Source

impl Display for Arguments<'_>

1.0.0 · Source

impl Display for source2_demo::proto::prost::alloc::fmt::Error

Source

impl Display for dyn Expected + '_

Source

impl<'a> Display for Unexpected<'a>

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for source2_demo::proto::prost::alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for source2_demo::proto::prost::alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for source2_demo::proto::prost::alloc::str::EscapeUnicode<'a>

Source

impl<'a> Display for TableSlice<'a>

Source

impl<'a, K, V, A> Display for source2_demo::proto::prost::alloc::collections::btree_map::OccupiedError<'a, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

Source

impl<'a, K, V, A> Display for std::collections::hash::map::OccupiedError<'a, K, V, A>
where K: Debug, V: Debug, A: Allocator,

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for Report<E>
where E: Error,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<K, V, S, A> Display for hashbrown::map::OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<T> Display for SendTimeoutError<T>

1.0.0 · Source

impl<T> Display for TrySendError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

1.0.0 · Source

impl<T> Display for SendError<T>

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T, A> Display for source2_demo::proto::prost::alloc::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for allocator_api2::stable::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<W> Display for std::io::buffered::IntoInnerError<W>

Source

impl<W> Display for bitter::writer::IntoInnerError<W>

Source

impl<W> Display for snap::error::IntoInnerError<W>