CCommunityGetClanAnnouncementsRequest

Struct CCommunityGetClanAnnouncementsRequest 

pub struct CCommunityGetClanAnnouncementsRequest {
Show 13 fields pub steamid: Option<u64>, pub offset: Option<u32>, pub count: Option<u32>, pub maxchars: Option<u32>, pub strip_html: Option<bool>, pub required_tags: Vec<String>, pub require_no_tags: Option<bool>, pub language_preference: Vec<u32>, pub hidden_only: Option<bool>, pub only_gid: Option<bool>, pub rtime_oldest_date: Option<u32>, pub include_hidden: Option<bool>, pub include_partner_events: Option<bool>,
}

Fields

steamid: Option<u64>offset: Option<u32>count: Option<u32>maxchars: Option<u32>strip_html: Option<bool>required_tags: Vec<String>require_no_tags: Option<bool>language_preference: Vec<u32>hidden_only: Option<bool>only_gid: Option<bool>rtime_oldest_date: Option<u32>include_hidden: Option<bool>include_partner_events: Option<bool>

Implementations

Source

impl CCommunityGetClanAnnouncementsRequest

pub fn steamid(&self) -> u64

Returns the value of steamid, or the default value if steamid is unset.

pub fn offset(&self) -> u32

Returns the value of offset, or the default value if offset is unset.

pub fn count(&self) -> u32

Returns the value of count, or the default value if count is unset.

pub fn maxchars(&self) -> u32

Returns the value of maxchars, or the default value if maxchars is unset.

pub fn strip_html(&self) -> bool

Returns the value of strip_html, or the default value if strip_html is unset.

pub fn require_no_tags(&self) -> bool

Returns the value of require_no_tags, or the default value if require_no_tags is unset.

pub fn hidden_only(&self) -> bool

Returns the value of hidden_only, or the default value if hidden_only is unset.

pub fn only_gid(&self) -> bool

Returns the value of only_gid, or the default value if only_gid is unset.

pub fn rtime_oldest_date(&self) -> u32

Returns the value of rtime_oldest_date, or the default value if rtime_oldest_date is unset.

pub fn include_hidden(&self) -> bool

Returns the value of include_hidden, or the default value if include_hidden is unset.

pub fn include_partner_events(&self) -> bool

Returns the value of include_partner_events, or the default value if include_partner_events is unset.