pub struct CMsgClientHello {Show 23 fields
pub version: Option<u32>,
pub socache_have_versions: Vec<CMsgSoCacheHaveVersion>,
pub client_session_need: Option<u32>,
pub client_launcher: Option<i32>,
pub secret_key: Option<String>,
pub client_language: Option<u32>,
pub engine: Option<i32>,
pub steamdatagram_login: Option<Vec<u8>>,
pub platform_id: Option<u32>,
pub game_msg: Option<Vec<u8>>,
pub os_type: Option<i32>,
pub render_system: Option<u32>,
pub render_system_req: Option<u32>,
pub screen_width: Option<u32>,
pub screen_height: Option<u32>,
pub screen_refresh: Option<u32>,
pub render_width: Option<u32>,
pub render_height: Option<u32>,
pub swap_width: Option<u32>,
pub swap_height: Option<u32>,
pub is_steam_china: Option<bool>,
pub is_steam_china_client: Option<bool>,
pub platform_name: Option<String>,
}Fields
version: Option<u32>socache_have_versions: Vec<CMsgSoCacheHaveVersion>client_session_need: Option<u32>client_launcher: Option<i32>secret_key: Option<String>client_language: Option<u32>engine: Option<i32>steamdatagram_login: Option<Vec<u8>>platform_id: Option<u32>game_msg: Option<Vec<u8>>os_type: Option<i32>render_system: Option<u32>render_system_req: Option<u32>screen_width: Option<u32>screen_height: Option<u32>screen_refresh: Option<u32>render_width: Option<u32>render_height: Option<u32>swap_width: Option<u32>swap_height: Option<u32>is_steam_china: Option<bool>is_steam_china_client: Option<bool>platform_name: Option<String>Implementations
Sourceimpl CMsgClientHello
impl CMsgClientHello
Sourcepub fn version(&self) -> u32
pub fn version(&self) -> u32
Returns the value of version, or the default value if version is unset.
Sourcepub fn client_session_need(&self) -> u32
pub fn client_session_need(&self) -> u32
Returns the value of client_session_need, or the default value if client_session_need is unset.
Sourcepub fn client_launcher(&self) -> PartnerAccountType
pub fn client_launcher(&self) -> PartnerAccountType
Returns the enum value of client_launcher, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_client_launcher(&mut self, value: PartnerAccountType)
pub fn set_client_launcher(&mut self, value: PartnerAccountType)
Sets client_launcher to the provided enum value.
Sourcepub fn secret_key(&self) -> &str
pub fn secret_key(&self) -> &str
Returns the value of secret_key, or the default value if secret_key is unset.
Sourcepub fn client_language(&self) -> u32
pub fn client_language(&self) -> u32
Returns the value of client_language, or the default value if client_language is unset.
Sourcepub fn engine(&self) -> ESourceEngine
pub fn engine(&self) -> ESourceEngine
Returns the enum value of engine, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_engine(&mut self, value: ESourceEngine)
pub fn set_engine(&mut self, value: ESourceEngine)
Sets engine to the provided enum value.
Sourcepub fn steamdatagram_login(&self) -> &[u8] ⓘ
pub fn steamdatagram_login(&self) -> &[u8] ⓘ
Returns the value of steamdatagram_login, or the default value if steamdatagram_login is unset.
Sourcepub fn platform_id(&self) -> u32
pub fn platform_id(&self) -> u32
Returns the value of platform_id, or the default value if platform_id is unset.
Sourcepub fn game_msg(&self) -> &[u8] ⓘ
pub fn game_msg(&self) -> &[u8] ⓘ
Returns the value of game_msg, or the default value if game_msg is unset.
Sourcepub fn os_type(&self) -> i32
pub fn os_type(&self) -> i32
Returns the value of os_type, or the default value if os_type is unset.
Sourcepub fn render_system(&self) -> u32
pub fn render_system(&self) -> u32
Returns the value of render_system, or the default value if render_system is unset.
Sourcepub fn render_system_req(&self) -> u32
pub fn render_system_req(&self) -> u32
Returns the value of render_system_req, or the default value if render_system_req is unset.
Sourcepub fn screen_width(&self) -> u32
pub fn screen_width(&self) -> u32
Returns the value of screen_width, or the default value if screen_width is unset.
Sourcepub fn screen_height(&self) -> u32
pub fn screen_height(&self) -> u32
Returns the value of screen_height, or the default value if screen_height is unset.
Sourcepub fn screen_refresh(&self) -> u32
pub fn screen_refresh(&self) -> u32
Returns the value of screen_refresh, or the default value if screen_refresh is unset.
Sourcepub fn render_width(&self) -> u32
pub fn render_width(&self) -> u32
Returns the value of render_width, or the default value if render_width is unset.
Sourcepub fn render_height(&self) -> u32
pub fn render_height(&self) -> u32
Returns the value of render_height, or the default value if render_height is unset.
Sourcepub fn swap_width(&self) -> u32
pub fn swap_width(&self) -> u32
Returns the value of swap_width, or the default value if swap_width is unset.
Sourcepub fn swap_height(&self) -> u32
pub fn swap_height(&self) -> u32
Returns the value of swap_height, or the default value if swap_height is unset.
Sourcepub fn is_steam_china(&self) -> bool
pub fn is_steam_china(&self) -> bool
Returns the value of is_steam_china, or the default value if is_steam_china is unset.
Sourcepub fn platform_name(&self) -> &str
pub fn platform_name(&self) -> &str
Returns the value of platform_name, or the default value if platform_name is unset.
Sourcepub fn is_steam_china_client(&self) -> bool
pub fn is_steam_china_client(&self) -> bool
Returns the value of is_steam_china_client, or the default value if is_steam_china_client is unset.