pub struct CMsgClientWelcome {Show 16 fields
pub version: Option<u32>,
pub game_data: Option<Vec<u8>>,
pub outofdate_subscribed_caches: Vec<CMsgSoCacheSubscribed>,
pub uptodate_subscribed_caches: Vec<CMsgSoCacheSubscriptionCheck>,
pub location: Option<Location>,
pub gc_socache_file_version: Option<u32>,
pub txn_country_code: Option<String>,
pub game_data2: Option<Vec<u8>>,
pub rtime32_gc_welcome_timestamp: Option<u32>,
pub currency: Option<u32>,
pub balance: Option<u32>,
pub balance_url: Option<String>,
pub has_accepted_china_ssa: Option<bool>,
pub is_banned_steam_china: Option<bool>,
pub additional_welcome_msgs: Option<CExtraMsgBlock>,
pub steam_learn_server_info: Option<CMsgSteamLearnServerInfo>,
}Fields
version: Option<u32>game_data: Option<Vec<u8>>outofdate_subscribed_caches: Vec<CMsgSoCacheSubscribed>uptodate_subscribed_caches: Vec<CMsgSoCacheSubscriptionCheck>location: Option<Location>gc_socache_file_version: Option<u32>txn_country_code: Option<String>game_data2: Option<Vec<u8>>rtime32_gc_welcome_timestamp: Option<u32>currency: Option<u32>balance: Option<u32>balance_url: Option<String>has_accepted_china_ssa: Option<bool>is_banned_steam_china: Option<bool>additional_welcome_msgs: Option<CExtraMsgBlock>steam_learn_server_info: Option<CMsgSteamLearnServerInfo>Implementations
Sourceimpl CMsgClientWelcome
impl CMsgClientWelcome
Sourcepub fn version(&self) -> u32
pub fn version(&self) -> u32
Returns the value of version, or the default value if version is unset.
Sourcepub fn game_data(&self) -> &[u8] ⓘ
pub fn game_data(&self) -> &[u8] ⓘ
Returns the value of game_data, or the default value if game_data is unset.
Sourcepub fn gc_socache_file_version(&self) -> u32
pub fn gc_socache_file_version(&self) -> u32
Returns the value of gc_socache_file_version, or the default value if gc_socache_file_version is unset.
Sourcepub fn txn_country_code(&self) -> &str
pub fn txn_country_code(&self) -> &str
Returns the value of txn_country_code, or the default value if txn_country_code is unset.
Sourcepub fn game_data2(&self) -> &[u8] ⓘ
pub fn game_data2(&self) -> &[u8] ⓘ
Returns the value of game_data2, or the default value if game_data2 is unset.
Sourcepub fn rtime32_gc_welcome_timestamp(&self) -> u32
pub fn rtime32_gc_welcome_timestamp(&self) -> u32
Returns the value of rtime32_gc_welcome_timestamp, or the default value if rtime32_gc_welcome_timestamp is unset.
Sourcepub fn currency(&self) -> u32
pub fn currency(&self) -> u32
Returns the value of currency, or the default value if currency is unset.
Sourcepub fn balance(&self) -> u32
pub fn balance(&self) -> u32
Returns the value of balance, or the default value if balance is unset.
Sourcepub fn balance_url(&self) -> &str
pub fn balance_url(&self) -> &str
Returns the value of balance_url, or the default value if balance_url is unset.
Sourcepub fn has_accepted_china_ssa(&self) -> bool
pub fn has_accepted_china_ssa(&self) -> bool
Returns the value of has_accepted_china_ssa, or the default value if has_accepted_china_ssa is unset.
Sourcepub fn is_banned_steam_china(&self) -> bool
pub fn is_banned_steam_china(&self) -> bool
Returns the value of is_banned_steam_china, or the default value if is_banned_steam_china is unset.