pub struct CMsgClothEffectAnimEvent {
pub source_entity_index: Option<i32>,
pub effect_name_hash: Option<i32>,
pub operation: Option<i32>,
pub flags: Option<i32>,
pub tags: Option<String>,
pub pte: Option<CMsgVector>,
}Fields
source_entity_index: Option<i32>effect_name_hash: Option<i32>operation: Option<i32>flags: Option<i32>pte: Option<CMsgVector>Implementations
Sourceimpl CMsgClothEffectAnimEvent
impl CMsgClothEffectAnimEvent
Sourcepub fn source_entity_index(&self) -> i32
pub fn source_entity_index(&self) -> i32
Returns the value of source_entity_index, or the default value if source_entity_index is unset.
Sourcepub fn effect_name_hash(&self) -> i32
pub fn effect_name_hash(&self) -> i32
Returns the value of effect_name_hash, or the default value if effect_name_hash is unset.
Sourcepub fn operation(&self) -> i32
pub fn operation(&self) -> i32
Returns the value of operation, or the default value if operation is unset.
Returns the value of tags, or the default value if tags is unset.