pub struct CMsgClothStiffenAnimEvent {
pub source_entity_index: Option<i32>,
pub vertex_set_hash: Option<i32>,
pub intensity: Option<f32>,
pub length: Option<f32>,
pub speed_in: Option<f32>,
pub speed_out: Option<f32>,
}Fields
source_entity_index: Option<i32>vertex_set_hash: Option<i32>intensity: Option<f32>length: Option<f32>speed_in: Option<f32>speed_out: Option<f32>Implementations
Sourceimpl CMsgClothStiffenAnimEvent
impl CMsgClothStiffenAnimEvent
Sourcepub fn source_entity_index(&self) -> i32
pub fn source_entity_index(&self) -> i32
Returns the value of source_entity_index, or the default value if source_entity_index is unset.
Sourcepub fn vertex_set_hash(&self) -> i32
pub fn vertex_set_hash(&self) -> i32
Returns the value of vertex_set_hash, or the default value if vertex_set_hash is unset.
Sourcepub fn intensity(&self) -> f32
pub fn intensity(&self) -> f32
Returns the value of intensity, or the default value if intensity is unset.
Sourcepub fn length(&self) -> f32
pub fn length(&self) -> f32
Returns the value of length, or the default value if length is unset.