CMsgConnectionStatus

Struct CMsgConnectionStatus 

pub struct CMsgConnectionStatus {
    pub status: Option<i32>,
    pub client_session_need: Option<u32>,
    pub queue_position: Option<i32>,
    pub queue_size: Option<i32>,
    pub wait_seconds: Option<i32>,
    pub estimated_wait_seconds_remaining: Option<i32>,
}

Fields

status: Option<i32>client_session_need: Option<u32>queue_position: Option<i32>queue_size: Option<i32>wait_seconds: Option<i32>estimated_wait_seconds_remaining: Option<i32>

Implementations

Source

impl CMsgConnectionStatus

pub fn status(&self) -> GcConnectionStatus

Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.

pub fn set_status(&mut self, value: GcConnectionStatus)

Sets status to the provided enum value.

pub fn client_session_need(&self) -> u32

Returns the value of client_session_need, or the default value if client_session_need is unset.

pub fn queue_position(&self) -> i32

Returns the value of queue_position, or the default value if queue_position is unset.

pub fn queue_size(&self) -> i32

Returns the value of queue_size, or the default value if queue_size is unset.

pub fn wait_seconds(&self) -> i32

Returns the value of wait_seconds, or the default value if wait_seconds is unset.

pub fn estimated_wait_seconds_remaining(&self) -> i32

Returns the value of estimated_wait_seconds_remaining, or the default value if estimated_wait_seconds_remaining is unset.