CMsgItemAcknowledged

Struct CMsgItemAcknowledged 

pub struct CMsgItemAcknowledged {
    pub account_id: Option<u32>,
    pub inventory: Option<u32>,
    pub def_index: Option<u32>,
    pub quality: Option<u32>,
    pub rarity: Option<u32>,
    pub origin: Option<u32>,
}

Fields

account_id: Option<u32>inventory: Option<u32>def_index: Option<u32>quality: Option<u32>rarity: Option<u32>origin: Option<u32>

Implementations

Source

impl CMsgItemAcknowledged

pub fn account_id(&self) -> u32

Returns the value of account_id, or the default value if account_id is unset.

pub fn inventory(&self) -> u32

Returns the value of inventory, or the default value if inventory is unset.

pub fn def_index(&self) -> u32

Returns the value of def_index, or the default value if def_index is unset.

pub fn quality(&self) -> u32

Returns the value of quality, or the default value if quality is unset.

pub fn rarity(&self) -> u32

Returns the value of rarity, or the default value if rarity is unset.

pub fn origin(&self) -> u32

Returns the value of origin, or the default value if origin is unset.