pub struct CMsgServerNetworkStats {Show 25 fields
pub dedicated: Option<bool>,
pub cpu_usage: Option<i32>,
pub memory_used_mb: Option<i32>,
pub memory_free_mb: Option<i32>,
pub uptime: Option<i32>,
pub spawn_count: Option<i32>,
pub num_clients: Option<i32>,
pub num_bots: Option<i32>,
pub num_spectators: Option<i32>,
pub num_tv_relays: Option<i32>,
pub fps: Option<f32>,
pub ports: Vec<Port>,
pub avg_ping_ms: Option<f32>,
pub avg_engine_latency_out: Option<f32>,
pub avg_packets_out: Option<f32>,
pub avg_packets_in: Option<f32>,
pub avg_loss_out: Option<f32>,
pub avg_loss_in: Option<f32>,
pub avg_data_out: Option<f32>,
pub avg_data_in: Option<f32>,
pub total_data_in: Option<u64>,
pub total_packets_in: Option<u64>,
pub total_data_out: Option<u64>,
pub total_packets_out: Option<u64>,
pub players: Vec<Player>,
}Fields
dedicated: Option<bool>cpu_usage: Option<i32>memory_used_mb: Option<i32>memory_free_mb: Option<i32>uptime: Option<i32>spawn_count: Option<i32>num_clients: Option<i32>num_bots: Option<i32>num_spectators: Option<i32>num_tv_relays: Option<i32>fps: Option<f32>ports: Vec<Port>avg_ping_ms: Option<f32>avg_engine_latency_out: Option<f32>avg_packets_out: Option<f32>avg_packets_in: Option<f32>avg_loss_out: Option<f32>avg_loss_in: Option<f32>avg_data_out: Option<f32>avg_data_in: Option<f32>total_data_in: Option<u64>total_packets_in: Option<u64>total_data_out: Option<u64>total_packets_out: Option<u64>players: Vec<Player>Implementations
Sourceimpl CMsgServerNetworkStats
impl CMsgServerNetworkStats
Sourcepub fn dedicated(&self) -> bool
pub fn dedicated(&self) -> bool
Returns the value of dedicated, or the default value if dedicated is unset.
Sourcepub fn cpu_usage(&self) -> i32
pub fn cpu_usage(&self) -> i32
Returns the value of cpu_usage, or the default value if cpu_usage is unset.
Sourcepub fn memory_used_mb(&self) -> i32
pub fn memory_used_mb(&self) -> i32
Returns the value of memory_used_mb, or the default value if memory_used_mb is unset.
Sourcepub fn memory_free_mb(&self) -> i32
pub fn memory_free_mb(&self) -> i32
Returns the value of memory_free_mb, or the default value if memory_free_mb is unset.
Sourcepub fn uptime(&self) -> i32
pub fn uptime(&self) -> i32
Returns the value of uptime, or the default value if uptime is unset.
Sourcepub fn spawn_count(&self) -> i32
pub fn spawn_count(&self) -> i32
Returns the value of spawn_count, or the default value if spawn_count is unset.
Sourcepub fn num_clients(&self) -> i32
pub fn num_clients(&self) -> i32
Returns the value of num_clients, or the default value if num_clients is unset.
Sourcepub fn num_bots(&self) -> i32
pub fn num_bots(&self) -> i32
Returns the value of num_bots, or the default value if num_bots is unset.
Sourcepub fn num_spectators(&self) -> i32
pub fn num_spectators(&self) -> i32
Returns the value of num_spectators, or the default value if num_spectators is unset.
Sourcepub fn num_tv_relays(&self) -> i32
pub fn num_tv_relays(&self) -> i32
Returns the value of num_tv_relays, or the default value if num_tv_relays is unset.
Sourcepub fn avg_ping_ms(&self) -> f32
pub fn avg_ping_ms(&self) -> f32
Returns the value of avg_ping_ms, or the default value if avg_ping_ms is unset.
Sourcepub fn avg_engine_latency_out(&self) -> f32
pub fn avg_engine_latency_out(&self) -> f32
Returns the value of avg_engine_latency_out, or the default value if avg_engine_latency_out is unset.
Sourcepub fn avg_packets_out(&self) -> f32
pub fn avg_packets_out(&self) -> f32
Returns the value of avg_packets_out, or the default value if avg_packets_out is unset.
Sourcepub fn avg_packets_in(&self) -> f32
pub fn avg_packets_in(&self) -> f32
Returns the value of avg_packets_in, or the default value if avg_packets_in is unset.
Sourcepub fn avg_loss_out(&self) -> f32
pub fn avg_loss_out(&self) -> f32
Returns the value of avg_loss_out, or the default value if avg_loss_out is unset.
Sourcepub fn avg_loss_in(&self) -> f32
pub fn avg_loss_in(&self) -> f32
Returns the value of avg_loss_in, or the default value if avg_loss_in is unset.
Sourcepub fn avg_data_out(&self) -> f32
pub fn avg_data_out(&self) -> f32
Returns the value of avg_data_out, or the default value if avg_data_out is unset.
Sourcepub fn avg_data_in(&self) -> f32
pub fn avg_data_in(&self) -> f32
Returns the value of avg_data_in, or the default value if avg_data_in is unset.
Sourcepub fn total_data_in(&self) -> u64
pub fn total_data_in(&self) -> u64
Returns the value of total_data_in, or the default value if total_data_in is unset.
Sourcepub fn total_packets_in(&self) -> u64
pub fn total_packets_in(&self) -> u64
Returns the value of total_packets_in, or the default value if total_packets_in is unset.
Sourcepub fn total_data_out(&self) -> u64
pub fn total_data_out(&self) -> u64
Returns the value of total_data_out, or the default value if total_data_out is unset.
Sourcepub fn total_packets_out(&self) -> u64
pub fn total_packets_out(&self) -> u64
Returns the value of total_packets_out, or the default value if total_packets_out is unset.