pub struct CNetMsgSpawnGroupLoad {Show 20 fields
pub worldname: Option<String>,
pub entitylumpname: Option<String>,
pub entityfiltername: Option<String>,
pub spawngrouphandle: Option<u32>,
pub spawngroupownerhandle: Option<u32>,
pub world_offset_pos: Option<CMsgVector>,
pub world_offset_angle: Option<CMsgQAngle>,
pub spawngroupmanifest: Option<Vec<u8>>,
pub flags: Option<u32>,
pub tickcount: Option<i32>,
pub manifestincomplete: Option<bool>,
pub localnamefixup: Option<String>,
pub parentnamefixup: Option<String>,
pub manifestloadpriority: Option<i32>,
pub worldgroupid: Option<u32>,
pub creationsequence: Option<u32>,
pub savegamefilename: Option<String>,
pub spawngroupparenthandle: Option<u32>,
pub leveltransition: Option<bool>,
pub worldgroupname: Option<String>,
}Fields
worldname: Option<String>entitylumpname: Option<String>entityfiltername: Option<String>spawngrouphandle: Option<u32>spawngroupownerhandle: Option<u32>world_offset_pos: Option<CMsgVector>world_offset_angle: Option<CMsgQAngle>spawngroupmanifest: Option<Vec<u8>>flags: Option<u32>tickcount: Option<i32>manifestincomplete: Option<bool>localnamefixup: Option<String>parentnamefixup: Option<String>manifestloadpriority: Option<i32>worldgroupid: Option<u32>creationsequence: Option<u32>savegamefilename: Option<String>spawngroupparenthandle: Option<u32>leveltransition: Option<bool>worldgroupname: Option<String>Implementations
Sourceimpl CNetMsgSpawnGroupLoad
impl CNetMsgSpawnGroupLoad
Sourcepub fn worldname(&self) -> &str
pub fn worldname(&self) -> &str
Returns the value of worldname, or the default value if worldname is unset.
Sourcepub fn entitylumpname(&self) -> &str
pub fn entitylumpname(&self) -> &str
Returns the value of entitylumpname, or the default value if entitylumpname is unset.
Sourcepub fn entityfiltername(&self) -> &str
pub fn entityfiltername(&self) -> &str
Returns the value of entityfiltername, or the default value if entityfiltername is unset.
Sourcepub fn spawngrouphandle(&self) -> u32
pub fn spawngrouphandle(&self) -> u32
Returns the value of spawngrouphandle, or the default value if spawngrouphandle is unset.
Sourcepub fn spawngroupownerhandle(&self) -> u32
pub fn spawngroupownerhandle(&self) -> u32
Returns the value of spawngroupownerhandle, or the default value if spawngroupownerhandle is unset.
Sourcepub fn spawngroupmanifest(&self) -> &[u8] ⓘ
pub fn spawngroupmanifest(&self) -> &[u8] ⓘ
Returns the value of spawngroupmanifest, or the default value if spawngroupmanifest is unset.
Sourcepub fn tickcount(&self) -> i32
pub fn tickcount(&self) -> i32
Returns the value of tickcount, or the default value if tickcount is unset.
Sourcepub fn manifestincomplete(&self) -> bool
pub fn manifestincomplete(&self) -> bool
Returns the value of manifestincomplete, or the default value if manifestincomplete is unset.
Sourcepub fn localnamefixup(&self) -> &str
pub fn localnamefixup(&self) -> &str
Returns the value of localnamefixup, or the default value if localnamefixup is unset.
Sourcepub fn parentnamefixup(&self) -> &str
pub fn parentnamefixup(&self) -> &str
Returns the value of parentnamefixup, or the default value if parentnamefixup is unset.
Sourcepub fn manifestloadpriority(&self) -> i32
pub fn manifestloadpriority(&self) -> i32
Returns the value of manifestloadpriority, or the default value if manifestloadpriority is unset.
Sourcepub fn worldgroupid(&self) -> u32
pub fn worldgroupid(&self) -> u32
Returns the value of worldgroupid, or the default value if worldgroupid is unset.
Sourcepub fn creationsequence(&self) -> u32
pub fn creationsequence(&self) -> u32
Returns the value of creationsequence, or the default value if creationsequence is unset.
Sourcepub fn savegamefilename(&self) -> &str
pub fn savegamefilename(&self) -> &str
Returns the value of savegamefilename, or the default value if savegamefilename is unset.
Sourcepub fn spawngroupparenthandle(&self) -> u32
pub fn spawngroupparenthandle(&self) -> u32
Returns the value of spawngroupparenthandle, or the default value if spawngroupparenthandle is unset.
Sourcepub fn leveltransition(&self) -> bool
pub fn leveltransition(&self) -> bool
Returns the value of leveltransition, or the default value if leveltransition is unset.
Sourcepub fn worldgroupname(&self) -> &str
pub fn worldgroupname(&self) -> &str
Returns the value of worldgroupname, or the default value if worldgroupname is unset.