pub struct CSource2MetricsFetchMapDataResponse {
pub results: Vec<MapData>,
}Fields
results: Vec<MapData>Trait Implementations
Sourceimpl Clone for CSource2MetricsFetchMapDataResponse
impl Clone for CSource2MetricsFetchMapDataResponse
Sourcefn clone(&self) -> CSource2MetricsFetchMapDataResponse
fn clone(&self) -> CSource2MetricsFetchMapDataResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CSource2MetricsFetchMapDataResponse
impl Default for CSource2MetricsFetchMapDataResponse
Sourcefn default() -> CSource2MetricsFetchMapDataResponse
fn default() -> CSource2MetricsFetchMapDataResponse
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CSource2MetricsFetchMapDataResponse
impl<'de> Deserialize<'de> for CSource2MetricsFetchMapDataResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CSource2MetricsFetchMapDataResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CSource2MetricsFetchMapDataResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for CSource2MetricsFetchMapDataResponse
impl Message for CSource2MetricsFetchMapDataResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CSource2MetricsFetchMapDataResponse
impl PartialEq for CSource2MetricsFetchMapDataResponse
Sourcefn eq(&self, other: &CSource2MetricsFetchMapDataResponse) -> bool
fn eq(&self, other: &CSource2MetricsFetchMapDataResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CSource2MetricsFetchMapDataResponse
impl Serialize for CSource2MetricsFetchMapDataResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for CSource2MetricsFetchMapDataResponse