CUserMessageRequestInventory

Struct CUserMessageRequestInventory 

pub struct CUserMessageRequestInventory {
    pub inventory: Option<i32>,
    pub offset: Option<i32>,
    pub options: Option<i32>,
}

Fields

inventory: Option<i32>offset: Option<i32>options: Option<i32>

Implementations

Source

impl CUserMessageRequestInventory

pub fn inventory(&self) -> i32

Returns the value of inventory, or the default value if inventory is unset.

pub fn offset(&self) -> i32

Returns the value of offset, or the default value if offset is unset.

pub fn options(&self) -> i32

Returns the value of options, or the default value if options is unset.