pub struct GameEventList { /* private fields */ }Expand description
Container for all game event definitions in a replay.
This stores the complete definitions for all game events that can occur during replay parsing. Each event definition specifies:
- Event ID: Unique identifier
- Event name: Human-readable name
- Key definitions: Names and types of fields in the event
Examples
use source2_demo::prelude::*;
// Game events are automatically parsed from the event definitions
// You access them through the observer callbacks or game event iterationTrait Implementations
Sourceimpl Default for GameEventList
impl Default for GameEventList
Sourcefn default() -> GameEventList
fn default() -> GameEventList
Returns the “default value” for a type. Read more