pub trait FieldRewriteResult {
// Required method
fn into_field_rewrite_result(self) -> Option<FieldValue>;
}Expand description
Converts a field rewrite handler result into an optional replacement.
Returning a plain value replaces the field. Returning Option<T> allows a
handler to keep the original field by returning None.
Required Methods
Sourcefn into_field_rewrite_result(self) -> Option<FieldValue>
fn into_field_rewrite_result(self) -> Option<FieldValue>
Converts this handler result into an optional FieldValue.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".