pub enum MessageRewrite {
Keep,
Rewrite,
Replace(Vec<u8>),
Drop,
}Expand description
Outcome for a message rewrite operation.
Variants
Keep
Leave the message unchanged.
Rewrite
Encode the mutated decoded message and replace the payload.
Use this after changing a decoded protobuf message in place.
Replace(Vec<u8>)
Replace the message payload with the provided bytes.
Drop
Drop the message entirely.