pub struct PacketMessage {
pub msg_type: i32,
pub payload: Vec<u8>,
}Expand description
Packet message passed to packet-list rewriters.
Fields
msg_type: i32Inner packet message type.
payload: Vec<u8>Encoded inner packet message payload.
Implementations
Sourceimpl PacketMessage
impl PacketMessage
Sourcepub fn new(msg_type: i32, payload: impl Into<Vec<u8>>) -> Self
pub fn new(msg_type: i32, payload: impl Into<Vec<u8>>) -> Self
Creates a packet message from a message type and encoded payload.
Sourcepub fn encoded<M>(msg_type: i32, message: &M) -> Selfwhere
M: Message,
pub fn encoded<M>(msg_type: i32, message: &M) -> Selfwhere
M: Message,
Creates a packet message by encoding a protobuf payload.
Sourcepub fn decode<M>(&self) -> Result<M, ParserError>
pub fn decode<M>(&self) -> Result<M, ParserError>
Decodes the packet message payload as a protobuf message.
Sourcepub fn replace_with<M>(&mut self, message: &M)where
M: Message,
pub fn replace_with<M>(&mut self, message: &M)where
M: Message,
Replaces the packet message payload with an encoded protobuf message.