pub struct RewriteInterests(/* private fields */);Expand description
Bitflags for declaring rewrite interests.
Use these flags in DemoRewriter::interests to specify which rewrite
callbacks your rewriter wants to receive. This lets
DemoWriter skip expensive decoding paths no
registered rewriter needs.
Implementations
Sourceimpl RewriteInterests
impl RewriteInterests
Sourcepub const DEMO_MESSAGE: Self
pub const DEMO_MESSAGE: Self
Interest in outer demo command payload rewrites.
Sourcepub const PACKET_MESSAGE: Self
pub const PACKET_MESSAGE: Self
Interest in individual packet message payload rewrites.
Sourcepub const PACKET_MESSAGES: Self
pub const PACKET_MESSAGES: Self
Interest in mutating the packet message list after per-message rewrites.
Sourcepub const DEMO_STRING_TABLES: Self
pub const DEMO_STRING_TABLES: Self
Interest in outer CDemoStringTables rewrites.
Sourcepub const STRING_TABLE_ENTRIES: Self
pub const STRING_TABLE_ENTRIES: Self
Interest in decoded string table entry updates.
Sourcepub const SVC_CREATE_STRING_TABLE: Self
pub const SVC_CREATE_STRING_TABLE: Self
Interest in svc_CreateStringTable rewrites.
Sourcepub const SVC_UPDATE_STRING_TABLE: Self
pub const SVC_UPDATE_STRING_TABLE: Self
Interest in svc_UpdateStringTable rewrites.
Sourcepub const ENTITY_FIELDS: Self
pub const ENTITY_FIELDS: Self
Interest in entity field replacement and entity rewrite filtering.
Sourceimpl RewriteInterests
impl RewriteInterests
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl RewriteInterests
impl RewriteInterests
Sourcepub const fn iter(&self) -> Iter<RewriteInterests>
pub const fn iter(&self) -> Iter<RewriteInterests>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RewriteInterests>
pub const fn iter_names(&self) -> IterNames<RewriteInterests>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.