#[uses_string_tables]Expand description
Marks the impl block to enable string table tracking.
When applied to an impl block or individual method, automatically enables
the STRING_TABLE_STATE interest flag so string tables are tracked during parsing.
Examples
#[observer]
#[uses_string_tables]
impl MyObs {
// Now you can use #[on_string_table] handlers
}